OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Adicionado aos favoritos",
    "Removed from favorites" : "Removido dos favoritos",
    "You added {file} to your favorites" : "Adicionou {file} aos seus favoritos",
    "You removed {file} from your favorites" : "Removeu {file} dos favoritos",
    "Favorites" : "Favoritos",
    "File changes" : "Alterações no ficheiro",
    "Created by {user}" : "Criado por {user}",
    "Changed by {user}" : "Modificado por {user}",
    "Deleted by {user}" : "Apagado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renomeado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote account\"" : "conta remota",
    "You created {file}" : "Criou {file}",
    "You created an encrypted file in {file}" : "Criou um ficheiro encriptado em {file}",
    "{user} created {file}" : "{user} criou {file}",
    "{user} created an encrypted file in {file}" : "{user} criou um ficheiro encriptado em {file}",
    "{file} was created in a public folder" : "{file} foi criado numa pasta pública",
    "You changed {file}" : "Alterou {file}",
    "You changed an encrypted file in {file}" : "Alterou um ficheiro encriptado em {file}",
    "{user} changed {file}" : "{user} modificou {file}",
    "{user} changed an encrypted file in {file}" : "{user} alterou um ficheiro encriptado em {file}",
    "You deleted {file}" : "Apagou {file}",
    "You deleted an encrypted file in {file}" : "Apagou um ficheiro encriptado em {file}",
    "{user} deleted {file}" : "{user} apagou {file}",
    "{user} deleted an encrypted file in {file}" : "{user} apagou um ficheiro encriptado em {file} ",
    "You restored {file}" : "Restaurou {file}",
    "{user} restored {file}" : "{user} restaurou {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Renomeou {oldfile} (oculto) para {newfile} (oculto)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Renomeou {oldfile} (oculto) para {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Renomeou {oldfile} para {newfile} (escondido)",
    "You renamed {oldfile} to {newfile}" : "Renomeou {oldfile} para {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} renomeou {oldfile} (escondido) para {newfile} (escondido)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} renomeou {oldfile} (escondido) para {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} renomeou {oldfile} para {newfile} (escondido)",
    "{user} renamed {oldfile} to {newfile}" : "{user} renomeou {oldfile} para {newfile}",
    "You moved {oldfile} to {newfile}" : "Moveu {oldfile} para {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} moveu {oldfile} para {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Um ficheiro foi adicionado ou removido dos seus <strong>favoritos</strong>",
    "Files" : "Ficheiros",
    "A file or folder has been <strong>changed</strong>" : "Foi <strong>alterado</strong> um ficheiro ou pasta",
    "A favorite file or folder has been <strong>changed</strong>" : "Uma pasta ou ficheiro favorito foi <strong>alterado</strong>",
    "Failed to authorize" : "Falhou a autorização",
    "Invalid folder path" : "Caminho da pasta inválido",
    "Folder not found" : "Pasta não encontrada",
    "No favorites" : "Sem favoritos",
    "Upload (max. %s)" : "Envio (máx. %s)",
    "Accept" : "Aceitar",
    "Reject" : "Rejeitar",
    "Incoming ownership transfer from {user}" : "Transferência de propriedade recebida de {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Quer aceitar {path} ?\n\nNota: O processo de transferência pode demorar até 1 hora após aceitar.",
    "Ownership transfer denied" : "Transferência de propriedade negada",
    "Your ownership transfer of {path} was denied by {user}." : "A sua transferência de propriedade de {path} foi negada por {user}.",
    "Ownership transfer failed" : "Transferência de propriedade falhou",
    "Your ownership transfer of {path} to {user} failed." : "A sua transferência de propriedade de {path} para {user} falhou.",
    "The ownership transfer of {path} from {user} failed." : "A transferência de propriedade de {path} de {user} falhou.",
    "Ownership transfer done" : "Transferência de propriedade concluída ",
    "Your ownership transfer of {path} to {user} has completed." : "A sua transferência de propriedade de {path} para {user} foi concluída.",
    "The ownership transfer of {path} from {user} has completed." : "A sua transferência de propriedade de {path} de {user} foi concluída",
    "in %s" : "em %s",
    "Transferred from %1$s on %2$s" : "Transferido de %1$s em %2$s",
    "Files compatibility" : "Compatibilidade de ficheiros",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permitir a restrição dos nomes de ficheiro para garantir que possam ser sincronizados com todos os clientes. Por predefinição, todos os nomes de ficheiro válidos em POSIX (por exemplo, Linux ou macOS) são permitidos.",
    "Enforce Windows compatibility" : "Forçar a compatibilidade com Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : " Isto bloqueará os nomes de ficheiro não válidos nos sistemas Windows, como a utilização de nomes reservados ou carateres especiais. Mas isto não irá impor a compatibilidade da sensibilidade à caixa alta maiúsculas ou baixa minúsculas.",
    "File Management" : "Gestão de ficheiros",
    "Home" : "Início",
    "Target folder does not exist any more" : "A pasta de destino já não existe",
    "Reload current directory" : "Recarregar a pasta atual",
    "Go to the \"{dir}\" directory" : "Ir para a pasta \"{dir}\"",
    "Current directory path" : "Caminho da pasta atual",
    "Your have used your space quota and cannot upload files anymore" : "Utilizou a sua quota de espaço e já não pode carregar mais ficheiros",
    "Drag and drop files here to upload" : "Arraste e largue os ficheiros aqui para carregar",
    "Favorite" : "Favorito",
    "Back" : "Voltar",
    "Toggle selection for file \"{displayName}\"" : "Alternar a seleção para o ficheiro \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Alternar a seleção para a pasta \"{displayName}\"",
    "File is loading" : "Ficheiro está a carregar",
    "Folder is loading" : "Pasta está a carregar",
    "Filename" : "Nome do ficheiro",
    "Folder name" : "Nome da pasta",
    "This node is unavailable" : "Este nó não está disponível",
    "Another entry with the same name already exists." : "Já existe outra entrada com o mesmo nome",
    "Invalid filename." : "Nome de ficheiro inválido",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Renomeado de \"{oldName}\" para \"{newName}\"",
    "Rename file" : "Renomear ficheiro",
    "Folder" : "Pasta",
    "Pending" : "Pendente",
    "Clear filter" : "Limpar filtro",
    "Modified" : "Modificado",
    "Type" : "Tipo",
    "Active filters" : "Filtros ativos",
    "Remove filter" : "Remover filtro",
    "Total rows summary" : "Resumo do total de linhas",
    "Toggle selection for all files and folders" : "Alternar a seleção para todos os ficheiros e pastas",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "\"{displayName}\" batch action executed successfully" : "Ação de lote “{displayName}” executada com sucesso",
    "\"{displayName}\" action failed" : "\"{displayName}\" a ação falhou",
    "Actions" : "Ações",
    "(selected)" : "(selecionado)",
    "List of files and folders." : "Lista de ficheiros e pastas.",
    "Column headers with buttons are sortable." : "Os cabeçalhos das colunas com botões são ordenáveis",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Por motivos de desempenho, esta lista não é totalmente processada. Os ficheiros serão processados à medida que navega na lista.",
    "File not found" : "Ficheiro não encontrado",
    "{count} selected" : "{count} selecionado ",
    "{usedQuotaByte} used" : "{usedQuotaByte} usado",
    "{used} of {quota} used" : "utilizado {used} de {quota}",
    "{relative}% used" : "{relative}% usado",
    "Could not refresh storage stats" : "Não foi possível atualizar as estatísticas de armazenamento",
    "Your storage is full, files can not be updated or synced anymore!" : "O seu armazenamento está cheio, os ficheiros já não podem ser atualizados ou sincronizados.",
    "Storage information" : "Informação de armazenamento",
    "Storage quota" : "Quota de armazenamento",
    "New folder" : "Nova pasta",
    "Create new folder" : "Criar nova pasta",
    "This name is already in use." : "Este nome já está em uso.",
    "Create" : "Criar",
    "Fill template fields" : "Preencher campos do modelo",
    "Submit" : "Submeter",
    "Choose a file or folder to transfer" : "Escolher um ficheiro ou pasta para transferir",
    "Transfer" : "Transfere",
    "Transfer {path} to {userid}" : "Transfere {path} para {userid}",
    "Invalid path selected" : "Caminho inválido selecionado",
    "Unknown error" : "Erro desconhecido",
    "Ownership transfer request sent" : "Pedido de transferência de propriedade enviado",
    "Cannot transfer ownership of a file or folder you do not own" : "Não é possível transferir a propriedade de um ficheiro ou pasta de que não é proprietário",
    "Transfer ownership of a file or folder" : "Transferir a propriedade de um ficheiro ou pasta",
    "Choose file or folder to transfer" : "Escolher ficheiro ou pasta para transferir",
    "Change" : "Mudar",
    "New owner" : "Novo proprietário",
    "Choose {file}" : "Escolher {file}",
    "Share" : "Partilhar",
    "Shared by link" : "Partilhado por hiperligação",
    "Shared" : "Partilhados",
    "Not enough free space" : "Espaço insuficiente",
    "Operation is blocked by access control" : "A operação está bloqueada pelo controlo de acesso",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\" ação executada com sucesso ",
    "Retry" : "Repetir",
    "No files in here" : "Nenhuns ficheiros aqui",
    "Upload some content or sync with your devices!" : "Envie algum conteúdo ou sincronize com os seus dispositivos!",
    "Go back" : "Voltar",
    "Views" : "Vistas",
    "Files settings" : "Definições do Ficheiros",
    "Show hidden files" : "Mostrar ficheiros ocultos",
    "Additional settings" : "Definições adicionais",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Copiar para área de transferência",
    "Keyboard shortcuts" : "Atalhos de teclado",
    "Navigation" : "Navegação",
    "View" : "Ver",
    "You" : "Vovê",
    "Owner" : "Proprietário",
    "Remove from favorites" : "Remover dos favoritos",
    "Add to favorites" : "Adicionar aos favoritos",
    "Tags" : "Etiquetas",
    "Leave this share" : "Sair desta partilha",
    "Disconnect storage" : "Desligar armazenamento",
    "Disconnect storages" : "Desligar armazenamentos",
    "Delete permanently" : "Eliminar permanentemente",
    "Delete file" : "Apagar ficheiro",
    "Delete folder" : "Apagar pasta",
    "Delete" : "Apagar",
    "Cancel" : "Cancelar",
    "Copy" : "Copiar",
    "Move" : "Mover",
    "Move or copy" : "Mover ou copiar",
    "Failed to redirect to client" : "Erro ao redirecionar para o cliente",
    "Rename" : "Renomear",
    "View in folder" : "Ver na pasta",
    "Today" : "Hoje",
    "Documents" : "Documentos",
    "Audio" : "Áudio",
    "Videos" : "Vídeos",
    "Templates" : "Modelos",
    "Some files could not be moved" : "Não foi possível mover alguns ficheiros",
    "This operation is forbidden" : "Esta operação é proibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta diretoria está indisponível, por favor, verifique os registos ou contacte o administrador",
    "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
    "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros","%n ficheiros"],
    "_%n folder_::_%n folders_" : ["%n pasta","%n pastas","%n pastas"],
    "No favorites yet" : "Sem favoritos",
    "Files and folders you mark as favorite will show up here" : "Os ficheiros e pastas que marcou como favoritos serão mostrados aqui",
    "All files" : "Todos os ficheiros",
    "Personal files" : "Ficheiros pessoais",
    "Recent" : "Recentes",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Select all" : "Selecionar todos",
    "Upload too large" : "Envio muito grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiros que está a tentar enviar excedem o tamanho máximo para os envios de ficheiro neste servidor.",
    "File could not be found" : "O ficheiro não foi encontrado",
    "Download" : "Transferir",
    "Show list view" : "Mostrar visualização em lista",
    "Show grid view" : "Mostrar visualização em grelha",
    "Close" : "Fechar",
    "Could not create folder \"{dir}\"" : "Não foi possível criar a pasta \"{dir}\"",
    "This will stop your current uploads." : "Isto irá interromper os seus carregamentos atuais.",
    "Upload cancelled." : "Envio cancelado.",
    "Processing files …" : "A processar ficheiros...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Não é possível enviar {filename}, porque este é uma diretoria ou tem 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Não existe espaço suficiente, está a enviar {size1} mas resta apenas {size2}",
    "Target folder \"{dir}\" does not exist any more" : "A pasta de destino \"{dir}\" já não existe",
    "An unknown error has occurred" : "Ocorreu um erro desconhecido",
    "File could not be uploaded" : "O ficheiro não foi carregado",
    "Uploading …" : "A carregar ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "O carregamento do item não é suportado",
    "Error when assembling chunks, status code {status}" : "Erro ao agregar partições, código de estado: {status}",
    "Choose target folder" : "Escolher pasta de destino",
    "Edit locally" : "Editar localmente",
    "Open" : "Abrir",
    "Could not load info for file \"{file}\"" : "Não foi possível carregar informações do ficheiro \"{file}\"",
    "Details" : "Detalhes",
    "Please select tag(s) to add to the selection" : "Selecione a(s) etiquetas(s) para adicionar à seleção ",
    "Apply tag(s) to selection" : "Aplicar etiqueta(s) à seleção",
    "Select directory \"{dirName}\"" : "Selecionar o diretório \"{dirName}\"",
    "Select file \"{fileName}\"" : "Selecionar o ficheiro \"{fileName}\"",
    "Unable to determine date" : "Não é possível determinar a data",
    "Could not move \"{file}\", target exists" : "Não foi possível mover \"{file}\", destino já existe",
    "Could not move \"{file}\"" : "Não foi possivel mover o ficheiro \"{file}\"",
    "copy" : "copiar",
    "Could not copy \"{file}\", target exists" : "Não foi possível copiar \"{file}\", o destino já existe",
    "Could not copy \"{file}\"" : "Impossível copiar \"{file}\"",
    "Copied {origin} inside {destination}" : "Copiado {origin} para {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiados {origin} e {nbfiles} outros ficheiros para dentro de {destination}",
    "{newName} already exists" : "{newName} já existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "Não foi possível renomear \"{fileName}\", este já não existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome \"{targetName}\" já está em utilização na pasta \"{dir}\". Por favor, escolha um nome diferente.",
    "Could not rename \"{fileName}\"" : "Não foi possível renomear \"{fileName}\"",
    "Could not create file \"{file}\"" : "Não foi possível criar o ficheiro \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Não foi possível criar o ficheiro \"{file}\", porque este já existe",
    "Could not create folder \"{dir}\" because it already exists" : "Não foi possível criar a pasta \"{dir}\", porque esta já existe",
    "Could not fetch file details \"{file}\"" : "Não foi possível obter os detalhes do ficheiro \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Erro ao eliminar o ficheiro \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nenhum resultado noutras pastas para {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Digite mais de dois caracteres para pesquisar noutras pastas",
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluindo %n ocultos","incluindo %n ocultos","incluindo %n ocultos"],
    "You do not have permission to upload or create files here" : "Não tem permissão para carregar ou criar ficheiros aqui",
    "_Uploading %n file_::_Uploading %n files_" : ["A enviar %n ficheiro","A enviar %n ficheiros","A enviar %n ficheiros"],
    "New" : "Novo",
    "New file/folder menu" : "Novo menu ficheiro/pasta",
    "Select file range" : "Selecionar o intervalo",
    "{used}%" : "{used}%",
    "{used} used" : "{used} utilizado",
    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de ficheiro inválido.",
    "File name cannot be empty." : "O nome do ficheiro não pode estar em branco.",
    "\"/\" is not allowed inside a file name." : "\"/\" não é permitido dentro de um nome de um ficheiro.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" não é um tipo de ficheiro permitido",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "O armazenamento de {owner} está cheio. Os ficheiros não podem ser enviados ou sincronizados.",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "A pasta de grupo \"{mountPoint}\" está quase cheia ({usedSpacePercent}%).",
    "Path" : "Caminho",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
    "Favorited" : "Nos Favoritos",
    "Upload file" : "Enviar ficheiro",
    "Not favorited" : "Não favorito",
    "An error occurred while trying to update the tags" : "Ocorreu um erro ao tentar atualizar as etiquetas",
    "{fileCount} files and {folderCount} folders" : "{fileCount} ficheiros e {folderCount} pastas",
    "Personal Files" : "Ficheiros pessoais",
    "Text file" : "Ficheiro de Texto",
    "New text file.txt" : "Novo texto ficheiro.txt",
    "Submitting fields…" : "Submeter campos…"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
